<?php

return [
    'Names' => [
        'SLE' => [
            0 => 'Le',
            1 => 'Sierra Leonean Leone',
        ],
    ],
];
